pub type PolledResult<O, I> = Poll<Result<Status<O, <I as Positioned>::Locator>, <I as TryStream>::Error>>;Expand description
The result type for poll_parse.
Aliased Type
pub enum PolledResult<O, I> {
Ready(Result<Status<O, <I as Positioned>::Locator>, <I as TryStream>::Error>),
Pending,
}Variants
Ready(Result<Status<O, <I as Positioned>::Locator>, <I as TryStream>::Error>)
Represents that a value is immediately ready.
Pending
Represents that a value is not ready yet.
When a function returns Pending, the function must also
ensure that the current task is scheduled to be awoken when
progress can be made.