Basic parsers and combinators.
Modules
- atomic
- Atomic parsers.
- combinator
- Parser combinators.
- iterable
- Tools for parsers return multiple outputs.
- wrapper
- Parsers to convert parse results or parser types.
Traits
Functions
- any
- Parses any token.
- choice
- A conventional function to produce a nested
orparser from a tuple of parsers. - eof
- Succeeds if the input reached the end.
- function
- Wraps the function into a parser or an iterable parser.
- is
- Parses a token matches the condition.
- is_not
- Parses a token does not match the condition.
- is_some
- Parses a token, pass the token to the function and succeeds if the returned value is
Some. - lazy
- Produces a parser (or an iterable parser) from the function at the time of parsing.
- none_of
- Succeeds if a parsed token doesn’t match one of the set.
- not
alloc - Parses any token except
token. - one_of
- Succeeds if a parsed token matches one of the set.
- position
- Returns the current position of input.
- tag
- Parses a static string like
tokens. - token
alloc - Parses a token.
- tokens
- Parses a sequence of tokens.
- value
- Produces a value without parsing any tokens.
- value_
fn - Produces a value by the function without parsing any tokens.