pub fn is_some<I, F, O>(cond: F) -> IsSome<I, F> ⓘwhere I: Positioned + ?Sized, F: FnMut(I::Ok) -> Option<O>,
Parses a token, pass the token to the function and succeeds if the returned value is Some.
Some